@@ -29,9 +29,6 @@
 
 #include "dhcpd.h"
 
-/* length of line we can read from the IF file, 256 is too small in some cases */
-#define IF_LINE_LENGTH 1024
-
 #define BSD_COMP		/* needed on Solaris for SIOCGLIFNUM */
 #include <sys/ioctl.h>
 #include <errno.h>
@@ -411,7 +408,7 @@ struct iface_info {
  */
 int 
 begin_iface_scan(struct iface_conf_list *ifaces) {
-	char buf[IF_LINE_LENGTH];
+	char buf[256];
 	int len;
 	int i;
 
@@ -484,7 +481,7 @@ begin_iface_scan(struct iface_conf_list *ifaces) {
  */
 static int
 next_iface4(struct iface_info *info, int *err, struct iface_conf_list *ifaces) {
-	char buf[IF_LINE_LENGTH];
+	char buf[256];
 	int len;
 	char *p;
 	char *name;
@@ -608,7 +605,7 @@ next_iface4(struct iface_info *info, int *err, struct iface_conf_list *ifaces) {
  */
 static int
 next_iface6(struct iface_info *info, int *err, struct iface_conf_list *ifaces) {
-	char buf[IF_LINE_LENGTH];
+	char buf[256];
 	int len;
 	char *p;
 	char *name;
