@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004 by Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (c) 2004,2009 by Internet Systems Consortium, Inc. ("ISC")
  * Copyright (c) 1996-2003 by Internet Software Consortium
  *
  * Permission to use, copy, modify, and distribute this software for any
@@ -18,7 +18,7 @@
  *   950 Charter Street
  *   Redwood City, CA 94063
  *   <info@isc.org>
- *   http://www.isc.org/
+ *   https://www.isc.org/
  */
 
 /*
@@ -47,7 +47,7 @@
  */
 
 #if !defined(LINT) && !defined(CODECENTER)
-static const char rcsid[] = "$Id: base64.c,v 1.2 2005/03/17 20:15:06 dhankins Exp $";
+static const char rcsid[] = "$Id: base64.c,v 1.6 2009/11/24 02:06:56 sar Exp $";
 #endif /* not lint */
 
 #include <sys/types.h>
@@ -64,7 +64,8 @@ static const char rcsid[] = "$Id: base64.c,v 1.2 2005/03/17 20:15:06 dhankins Ex
 
 #include <sys/socket.h>
 
-#include "minires/minires.h"
+#include "cdefs.h"
+#include "osdep.h"
 #include "arpa/nameser.h"
 
 #define Assert(Cond) if (!(Cond)) abort()
