@@ -4,7 +4,8 @@
 
 /*
  * Copyright (c) 1995 RadioMail Corporation.
- * Copyright (c) 2004 by Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (c) 2009,2014 by Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (c) 2004,2007 by Internet Systems Consortium, Inc. ("ISC")
  * Copyright (c) 1996-2003 by Internet Software Consortium
  *
  * Permission to use, copy, modify, and distribute this software for any
@@ -31,13 +32,11 @@
  * with Vixie Laboratories.
  */
 
-#ifndef lint
-static char copyright[] =
-"$Id: errwarn.c,v 1.10.140.1 2009/07/23 21:43:35 sar Exp $ Copyright (c) 2004 Internet Systems Consortium.  All rights reserved.\n";
-#endif /* not lint */
+#include "dhcpd.h"
 
 #include <omapip/omapip_p.h>
 #include <errno.h>
+#include <syslog.h>
 
 #ifdef DEBUG
 int log_perror = -1;
@@ -72,29 +71,19 @@ void log_fatal (const char * fmt, ... )
 
   /* Also log it to stderr? */
   if (log_perror) {
-	  write (STDERR_FILENO, mbuf, strlen (mbuf));
-	  write (STDERR_FILENO, "\n", 1);
+	  IGNORE_RET (write (STDERR_FILENO, mbuf, strlen (mbuf)));
+	  IGNORE_RET (write (STDERR_FILENO, "\n", 1));
   }
 
-#if !defined (NOMINUM)
   log_error ("%s", "");
-  log_error ("If you did not get this software from ftp.isc.org, please");
-  log_error ("get the latest from ftp.isc.org and install that before");
-  log_error ("requesting help.");
-  log_error ("%s", "");
-  log_error ("If you did get this software from ftp.isc.org and have not");
-  log_error ("yet read the README, please read it before requesting help.");
-  log_error ("If you intend to request help from the dhcp-server@isc.org");
-  log_error ("mailing list, please read the section on the README about");
-  log_error ("submitting bug reports and requests for help.");
-  log_error ("%s", "");
-  log_error ("Please do not under any circumstances send requests for");
-  log_error ("help directly to the authors of this software - please");
-  log_error ("send them to the appropriate mailing list as described in");
-  log_error ("the README file.");
+  log_error ("If you think you have received this message due to a bug rather");
+  log_error ("than a configuration issue please read the section on submitting");
+  log_error ("bugs on either our web page at www.isc.org or in the README file");
+  log_error ("before submitting a bug.  These pages explain the proper");
+  log_error ("process and the information we find helpful for debugging..");
   log_error ("%s", "");
   log_error ("exiting.");
-#endif
+
   if (log_cleanup)
 	  (*log_cleanup) ();
   exit (1);
@@ -120,8 +109,8 @@ int log_error (const char * fmt, ...)
 #endif
 
   if (log_perror) {
-	  write (STDERR_FILENO, mbuf, strlen (mbuf));
-	  write (STDERR_FILENO, "\n", 1);
+	  IGNORE_RET (write (STDERR_FILENO, mbuf, strlen (mbuf)));
+	  IGNORE_RET (write (STDERR_FILENO, "\n", 1));
   }
 
   return 0;
@@ -147,8 +136,8 @@ int log_info (const char *fmt, ...)
 #endif
 
   if (log_perror) {
-	  write (STDERR_FILENO, mbuf, strlen (mbuf));
-	  write (STDERR_FILENO, "\n", 1);
+	  IGNORE_RET (write (STDERR_FILENO, mbuf, strlen (mbuf)));
+	  IGNORE_RET (write (STDERR_FILENO, "\n", 1));
   }
 
   return 0;
@@ -174,8 +163,8 @@ int log_debug (const char *fmt, ...)
 #endif
 
   if (log_perror) {
-	  write (STDERR_FILENO, mbuf, strlen (mbuf));
-	  write (STDERR_FILENO, "\n", 1);
+	  IGNORE_RET (write (STDERR_FILENO, mbuf, strlen (mbuf)));
+	  IGNORE_RET (write (STDERR_FILENO, "\n", 1));
   }
 
   return 0;
